@@ -1,4 +1,5 @@
 
+# switch allele so that effect allele frequency < 0.5
 align.reference <- function(ref.geno, allele.info, options){
   
   msg <- paste("Realigning allele information of reference:", date())
@@ -16,18 +17,19 @@ align.reference <- function(ref.geno, allele.info, options){
     ra[id] <- allele.info$EffectAllele[id]
     allele.info$EffectAllele <- ea
     allele.info$RefAllele <- ra
+    ref.geno[, id] <- (2 - ref.geno[, id])
   }
   
-  foo <- function(g){
-    f <- mean(g, na.rm = TRUE)/2
-    if(f > .5){
-      return(2 - g)
-    }else{
-      return(g)
-    }
-  }
-  ref.geno <- apply(ref.geno, 2, foo)
-  colnames(ref.geno) <- rs
+  # foo <- function(g){
+  #   f <- mean(g, na.rm = TRUE)/2
+  #   if(f > .5){
+  #     return(2 - g)
+  #   }else{
+  #     return(g)
+  #   }
+  # }
+  # ref.geno <- apply(ref.geno, 2, foo)
+  # colnames(ref.geno) <- rs
   
   list(ref.geno = ref.geno, allele.info = allele.info)
   
