@@ -1,12 +1,15 @@
 
-meta <- function(summary.files, lambda = NULL, sel.snps = NULL, only.meta = TRUE){
+meta <- function(summary.files, lambda = NULL, sel.snps = NULL, only.meta=TRUE, ambig.by.AF=FALSE){
   
+  options <- list(ambig.by.AF=ambig.by.AF, print=TRUE)
+
   validate.summary.files(summary.files)
   
   lambda <- validate.lambda.summaryData(summary.files, lambda)
   
-  sf <- load.summary.files(summary.files, lambda, sel.snps)
-  
+  sf <- load.summary.files(summary.files, lambda, sel.snps, options)
+  if (ambig.by.AF) sf$stat <- align.ambig.meta(sf$stat)
+
   pos.info <- extract.position.information(sf$stat)
   
   ref.allele <- extract.reference.allele(sf$stat)
