@@ -18,6 +18,7 @@ warm.start <- function(setup, nperm = NULL, lambda = 1.0, nthread = NULL){
        accurate = test$accurate, test.timing = test$test.timing, 
        pathway = setup$pathway, meta.stat = setup$meta.stat, 
        deleted.snps = setup$deleted.snps, deleted.genes = setup$deleted.genes, 
-       options = setup$options, setup.timing = setup$setup.timing)
+       options = setup$options, setup.timing = setup$setup.timing, 
+       setup = setup)
   
 }
